Enum actix_web_httpauth::headers::www_authenticate::bearer::Error[][src]

pub enum Error {
    InvalidRequest,
    InvalidToken,
    InsufficientScope,
}

Bearer authorization error types, described in RFC 6750

Variants

The request is missing a required parameter, includes an unsupported parameter or parameter value, repeats the same parameter, uses more than one method for including an access token, or is otherwise malformed.

The access token provided is expired, revoked, malformed, or invalid for other reasons.

The request requires higher privileges than provided by the access token.

Methods

impl Error
[src]